# Discrete Mathematics

## Definitions
**Even Integer** ~ An integer x is \_\_\_ if there exists an integer k such that x = 2k
**Odd Integer** ~ An integer x is \_\_\_ if there exists an integer k such that x = 2k + 1
**Natural Numbers** ~ These are nonnegative integers N = {0, 1, 2, 3, ...}
**Rational Numbers** ~ These are numbers formed by dividing two integer p/q where q != 0. The symbol for this set is Q.
**Perfect Square** ~ An integer a is a \_\_\_ provided there exists an integer b such that a = b^2. 
**Square Root** ~ An integer b is a \_\_\_ provided there exists an integer a such that b^2 = a.

## Basic Structures
**Set** ~ This is an unordered collection of distinct objects, denoted by curly braces {}. Objects are separated with commas. %%{1, 2, 3, ...} The ... means and so on, meaning there is no end. %% &&The distinct objects are called **elements** or **members** of the set, and a set is said to **contain** its elements.&& &&We write a ∈ A to denote that a is an element of the set A, and a ∉ A denotes a is not an element of the set A. &&Two sets are **equal** iff they have the same elements = if ∀x(x ∈ A ↔ x ∈ B)&& &&A useful way to show that two sets have the same elemenst is to show that each set is a subset of the other.&&
**Null Set** ~ This is a set denoted by ∅ or {} and is special in that it has no elements. 
**Singleton set** ~ This is a set with one element. It is important to note that the set ∅ is an empty set, while the set {∅} is this.
**Multiset** ~ This is an unordered collection of objects where an element can occur as a member more than once. &&The numbers m_i, i = 1, 2, ..., r are called **multiplicities** of the elements a_i, i = 1, 2, ..., r. (Elements not in a multiset are assigned 0 as their multiplicity in this set)&&\[\{m_1 \cdot a_1, m_2 \cdot a_2, ..., m_r \cdot a_r\}\]

**Subset, Superset** ~ The set A is a \_\_\_ of B, and B is a \_\_\_ of A if and only if every element of A is also an element of B. &&We use the notation A ⊆ B to indicate that A is a subset of the set B. If, instead, we want to stress that B is a superset of A, we use the equivalent notation B ⊇ A. This is equivalent to ∀x(x ∈ A -> x ∈ B).&& &&When we wish to emphasize that a set A is a subset of set B but that A != B, we write A ⊂ B and say that A is a **proper subset** of B. For A ⊂ B to be true, it must be the case that A ⊆ B and there must exist an element x of B that is not an element of A. This is equivalent to ∀x(x ∈ A -> x ∈ B) ∧ ∃x(x ∈ B ∧ x ∉ A).&&

**Finite Set, Cardinality** ~ Let S be a set. If there are exactly n distinct elements in S where n is a nonnegative integer, we say that S is a \_\_\_ and that n is the \_\_\_ of S. &&The cardinality of S is denoted by |S|.&& &&A set is said to be **infinite** if it is not finite.&&

**Power Set** ~ Given a set S, the \_\_\_ of S is the set of all subsets of the set S. This is denoted by P(S). If a set has n elements, then this will always have 2^n elements. 

**Ordered n-Tuple** ~ The \_\_\_, denoted by (a1, a2, ..., a_n) is the ordered collection that has a1 as its first element, a2 as its second element, ..., and a_n as its nth element. We say two of these are equal if and only if each corresponding pair of their elements is equal. &&Ordered 2-tuples are called **ordered pairs**.&&

**Cartesian Product** ~ Let A and B be sets. The \_\_\_ of A and B, denoted by A X B, is the set of all ordered pairs (a, b), where a ∈ A and b ∈ B. \[A \times B  = \{(a, b) \mid a \in A \wedge b \in B\}\]

**Union of Sets** ~ Let A and B be sets. The \_\_\_ of the sets A and B, denoted by A ∪ B, is the set that contains those elements that are either in A or in B, or in both. This is the same as {x : x in A or x in B} \[A \cup B = \{x \mid x \in A \vee x \in B\}\]

**Intersection of Sets** ~ Let A and B be sets. The \_\_\_ of the sets A and B, denoted by A ∩ B, is the set containing those elements in both A and B. This is the same as {x : x in A and x in B}&&Two sets are called **disjoint** if their intersection is the empty set.&& \[A \cap B = \{x \mid x \in A \wedge x \in B\}\] 
**Difference of Sets** ~ Let A and B be sets. The \_\_\_ of A and B, denoted by A - B, is the set containing those elements that are in A but not B. This is the same as {x : x in A and x not in B}. &&The difference of A and B is also called the **complement** of B *with respect to* A.&& \[A - B = \{x \mid x \in A \wedge x \notin B\}\]

**Complement of Sets** ~ Let U be the universal set. The \_\_\_ of the set A, denoted by \(\bar{A}\), is the \_\_\_ of A with respect to U. Therefore, the \_\_\_ of the set A is U - A. \[\bar{A} = \{x \in U \mid x \notin A\}\]

**Symmetric Difference** ~ Let A and B be sets. The \_\_\_ of A and B, denoted by \(A \Delta B\), is the set of all ements in A but not B or in B but not A. Therefore, the \_\_\_ of the set A and B is equal to \((A - B) \cup (B - A)\). Prove also that this equals \(A \cup B - A \cap B\) 

**DeMorgan's Laws** ~ Let A, B, and C be sets. Then A - (B U C) = (A - B) \(\cap\) (A - C). And A - (B \(\cap\) C) = (A - B) U (A - C).

**Cartesian Product** ~ Let A and B be sets. The \_\_\_ of A and B, denoted A x B, is the set of all ordered pairs formed by taking an element from A together with an element from B in all possible ways. \[A \times B = \{(a, b) : a \in A, b \in B\}\]

Set Identities Table:
![](https://i.imgur.com/mifxQc3.png?1)

**Function** ~ Let A and B be nonempty sets. A \_\_\_ f from A to B is an assignment of exactly one element of B to each element of A. We write f(a) = b if b is the unique element oWe write f(a) = b if b is the unique element of B assigned by the \_\_\_ f to the element a of A. If f is a \_\_\_ from A to B, we write f : A -> B. &&A function f: A -> B can also be defined in terms as a relation from A to B that contains one and only one ordered pair (a, b) for every element a in A, where (a, b) is the unique ordered pair in the relation that has a as its first element. &&Functions are sometimes also called **mappings** or **transformations**. If f is a function from A to B, we say that f **maps** A to B.&& &&Two functions are equal when they have the same domain, codomain, and map each element of their common domain to the same element in their common codomain.&& &&Functions with the same domain and codomain can be added and multiplied: (f1 + f2)(x) = f1(x) + f2(x). (f1f2)(x) = f1(x)f2(x).&&

**Domain, Codomain** ~ If f is a function from A to B, we say that A is the (1)\_\_\_ of f and B is the (2)\_\_\_ of f. 
**Image, Preimage** ~ If f is a function from A to B, if f(a) = b, we say that b is the (1)\_\_\_ of a and a is a (2)\_\_\_ of b. The (1)\_\_\_ of f is the set of all (1)\_\_\_s of elements of A. &&The image is also called the **range** of f.&& &&Let f be a function from A to B and let S be a subset of A. The **image of a subset** S under the function f is the subset  of B that consists of the images of the elements of S. We denote the image of S by f(S), which is \(f(S) = \{t \mid \exists s \in S (t = f(s))\}\), or the shorthand \(\{f(s) \mid s \in S\}\).&& 

**One-to-one/Injection** ~ A function f from A to B is said to be \_\_\_, or an \_\_\_, if f(a) = f(b) implies that a = b for all a and b in the domain of f. Another way of saying this is that if a != b, then f(a) != f(b). &&A function is said to be **injective** if it is one-to-one.&&
**Onto/Surjection** ~ A function f from A to B is called \_\_\_, or a \_\_\_, if for every element b in B, there is an element a in A for which f(a) = b. Another way of saying this is that the range of f is equal to its codomain. &&A function is said to be **surjective** if it is onto.&&
**One-to-one Correspondence/Bijection** ~ A function f is a \_\_\_, or a \_\_\_, if it is both one-to-one and onto. &&We also say such a function is **bijective**.&&

**Proof help**: Suppose f : A -> B
    Injective: Show if f(x) = f(y), for arbitrary x, y in A, then x = y
    Not Injective: Find any x, y in A s.t. x != y and f(x) = f(y)
    Surjective: For arbitrary y in B, find x in A s.t. f(x) = y
    Not Surjective: Find any y in B s.t. f(x) != y for all x in A
    
**Inverse Function** ~ Let f be a bijection from set A to set B. The \_\_\_ of f is the function that assigns to an element b belonging to B the unique element a in A such that f(a) = b. The \_\_\_ of f is denoted by f^{-1}, hence f^{-1}(b) = a when f(a) = b.

**Invertible** ~ A bijection is called \_\_\_ if we can define an inverse of the bijection. It is not \_\_\_ if the function is not a bijection, because the inverse of such a function does not exist.
**Composition** ~ Let g be a function from~ Let g be a function from the set A to the set B and let f be a function from the set B to the set C. The \_\_\_ of the functions f and g, denoted for all a in A by \(f \circ g\), is the function from A to C defined by \((f \circ g)(a) = f(g(a))\).
**Graph** ~ Let f be a function from the set A to the set B. The \_\_\_ of the function f is the set of ordered pairs {(a, b) | a in A and f(a) = b}.
**Partial Function** ~ A \_\_\_ f from set A to a set B is an assignment to each element a in a subset of A, called the **domain of definition**in a subset of A, called the **domain of definition** of f, of a unique element b in B. We say that f is **undefined** for elements in A that are not in the domain of definition of f. &&When the domain of definition of f equals A, we say that f is a **total function**.&&

**Sequence** ~ A \_\_\_ is a function from a subset of the set of integers (usually either the set [0, 1, 2, ...] or the set [1, 2, 3, ...]) to a set S. We use the notation \(a_n\) to denote the image of the integer n. We call \(a_n\) a term of the \_\_\_.

**Geometric Progression** ~ A \_\_\_ is a sequence of the form \(a, ar, ar^2, \ldots, ar^n, \ldots\), where the *initial term* a and the *common ratio* r are real numbers.
**Arithmetic Progression** ~ A \_\_\_ is a sequence of the form \(a, a + d, a + 2d, \ldots, a + nd + \ldots\), where the *initial term* a and the *common diference* d are real numbers.

**Strings** ~ These are sequences of the form \(a_1, a_2, \ldots, a_n\) or \(a_1a_2 \ldots a_n\). &&The *length* of a string is the number of terms in it.&& &&The empty string, denoted by \(\lambda\), is the string that has no terms and length 0.&&

**Recurrence Relation** ~ This sequence is an equation that expresses \(a_n\) in terms of one or more of the previous terms of the sequence, namely \(a_0, a_1, \ldots, a_{n-1}\), for all integers n with \(n \geq n_0\), where n_0 is a nonnegative integer. &&A sequence is called a *solution* of a recurrence relation if its terms satisfy the recurrence relation.&& &&A recurrence relation is said to *recursively define* a sequence.&&

**Fibonacci Sequence** ~ The \_\_\_ \(f_0, f_1, f_2, \ldots\) is defined by the *initial conditions* \(f_0 = 0, f_1 = 1\), and the recurrence relation \(f_n = f_{n - 1} + f_{n - 2}\) for n = 2, 3, 4.

**Closed formula** ~ We say that we have solved the recurrence relation together with the initial conditions when we find an explicit formula, called a \_\_\_, for the terms of the sequence. 

**Iteration** ~ This is a technique that repeatedly uses a recurrence relation to try to find a solution to the relation. 

**Summation (Sum)** ~ Let m, n ∈ Z with m <= n. This symbol is read the \_\_\_ of \(a_k\) from k = m to n and is the sum \(a_m + a_m+1 + a_m+2 + \ldots + a_n-1 + a_n\). &&If m > n, there are no numbers to add. This is called an **empty sum**, which evaluates to 0.&& &&The variable k is called the *index of summation*, starting with its *lower limit* m and ending with its *upper limit* n. \[\sum_{k=m}^n a_k\]

**Geometric Series** ~ This is the summation of a geometric progression. \[\sum_{j=0}^n ar^j = \begin{cases} \frac{a(r^{n + 1} - 1)}{r - 1} \text{ if } r \neq 1 \\ (n + 1)a \text{ if } r = 1.\end{cases}\]

**Cardinality** ~ The sets A and B have the same \_\_\_ if and only if there is a bijection from A to B. When A and B have the same \_\_\_, we write |A| = |B|. If there is an injective function from A to B, |A| <= |B|, and if there is a surjective function from A to B, |A| >= |B|.

**Countable** ~ A set that is either finite or has the same cardinality as the set of positive integas the set of positive integers is called \_\_\_. When an infinite set S is \_\_\_, we denote the cardinaltiy of S by \(\aleph_0\).&&A set that is not countable is called uncountable.&& &&If A and B are countable sets, then A U B is also countable.&&

**Computable** ~ A function is \_\_\_ if there is a computer program in some programming language that finds the values of the function. &&If a function is not computable we say it is uncomputable.&&

## Number Theory
**Divides** ~ Let a and b be integers. We say that b \_\_\_ a provided there is an integer c such that bc = a. This is written as b | a. &&We can also say that a is divisible by b, b is a factor of a, or b is a divisor of a.&&
**The Division Algorithm** ~ Let a be an integer and d a positive integer. Then there are unique integers q and r, with 0 <= r <= d such that a = dq + r. Then q = a **div** d and r = a **mod** d.
**Congruence; Modulus** ~ If a and b are integers and m is a positive integer, then a is congruent to b modulo m if m divides a - b. We use the notation \(a \equiv b\) (mod m) to indicate that a is congruent to b modulo m. We say that \(a \equiv b\) (mod m) is a (1)\_\_\_ and that m is its (2)\_\_\_. If a and b are not congruent modulo m, we write \(a \not \equiv b\) (mod m).
**Modular Arithmetic** ~ All operations except for division proceed as expected: for n > 0, a, b in Z_n, a + b = (a + b) mod, etc. However, div However, division only exists and is defined as a / b = a * b^(-1) where the inverse only exists when b and n are coprime. 

**Prime** ~ An integer p is \_\_\_ if p > 1 and the only positive divisors of p are 1 and p.
**Composite** ~ An integer a is \_\_\_ if there exists an integer 1 < b < a such that b | a, or another way of saying this is that a can be written as the product of two positive integers m, n with 1 < m <= n < a.
**The Fundamental Theorem of Arithmetic** ~ This theorem states that every integer greater than 1 can be written uniquely as a prime or as the product of two or more primes, where the prime factors are written in order of nondecreasing size.
**Square-root Prime Divisor** ~ If n is a composite integer, then n has a prime divisor less than or equal to sqrt(n).
**Common Divisor** ~ Let a, b in Z. We callZ. We call d a \_\_\_ of a and b provided d | a and d | b.
**Greatest Common Divisor** ~ Let a, b in Z. We call d a \_\_\_ if 1) d | a and d | b  and d | b and 2) if e | a and e | b, then e <= d. A more common definition is that this of a, b is the smallest positive integer than can be written a
**Least Common Multiple** ~ Let a, b in Z. This is the smallest positive integer that is divisible by both a and b, denoted by lcm(a, b).

**Euclid's Algorithm (Pulverizer)** ~ Let a and b be positive integers. Then GCD(a, b) = GCD(b, a mod b).
**Coprime/Relatively Prime** ~ Let a and b be positive integers. a and b are \_\_\_ (1) if and only if GCD(a, b) = 1 and (2) if and only if ax + by = 1 for x, y in Z. &&The integers a1, a2, ..., an are **pairwise relatively prime** if gcd(ai, aj) = 1 whenever 1 <= i < j <= n.&&
**Bezout's Theorem** ~ If a and b are positive integers, then there exist integers s and t such that gcd(a, b) = sa + tb. 

**Cryptosystem** ~ This is a five-tuple (P, C, K, E, D), standing for plain-text strings, cipher-text strings, key space, encryption functions, and decryption functions respectively. We denote \(E_k\) and \(D_k\) as the encryption and decryption function corresponding to key k.


## Induction and Recursion

**Principle of Mathematical Induction** ~ This method provesproves that P(n) is true for all positive integers n, where P(n) is a propP(n) is a propositional function. It must complete two steps: (1) Verify that P(1) is true. (2) Show that the conditional statement P(k) -> P(k + 1) is true for all positive integers k. &&Step 1 is called the **basis step** and step 2 is called the **inductive step**. The assumption that P(k) is true is called the **inductive hypothesis**.&&
**Well-ordering Property** ~ This is an axiom for the set of positive integers that states that every nonempty subset of the set of positive integers has a least element. 
**Strong Induction** ~ This method proves that P(n) is true for all positive integers n, where P(n) is a propositional function, we complete two steps: (1) Verify that P(1) is true. (2) Show that the conditional statement [P(1) and P(2) and ... and P(].

## Counting

**Product Rule** ~ Suppose a procedure is carried out by performing tasks T1, T2, ..., Tm in that order. If T_i can be performed in n_i ways regardless of how the previous tasks were completed, then there are n1 * n2 * ... * n_m = n! ways in total to perform the procedure.
**Sum Rule** ~ Suppose that a task ca nbe done in one of n1 ways, in one of n2 ways, ..., or in one of n_m ways, where none of the set of n_i ways of doing the task is the same as any of the set of n_j ways, for all pairs i and j with 1 <= i < j <= m. Then the number of ways to do the task is n1 + n2 + ... + n_m. &&If A1, A2, ..., A_m are pairwise disjoint finite sets, then the number of elements in the union of these sets is the sum of the numbers of elements in the sets.%%
**Principle of Inclusion-Exclusion (Subtraction Rule)** ~ If a task can be done in either n1 ways or n2 ways, then the number of ways to do the task in n1 + n2 minus the number of ways to do the task that are common to the two different ways. &&Recall from set theory that the cardinality of the union between two sets A and B = |A U B| = |A| + |B| - |A ∩ B|
**Division Rule** ~ There are n/d ways to do a task if it can be done using a procedure that can be carried out in n ways, and for every way w, exactly d of the n ways correspond to way w. &&In terms of sets: If the finite set A is the union of n pairwise disjoint subsets each with d elements, then n = |A|/d.&& &&If f is a function from A to B where A and B are finite sets, and that for every value y ∈ B there are exactly d values x ∈ A such that f(x) = y, then |B| = |A|/d.&&

**Permutation** ~ A \_\_\_ of a set of distinct objects in an ordered arrangement of these objects. An ordered arrangement of r elements of a set is called an r-\_\_\_. The number of r-permutations of a set with n elements is denoted P(n, r) and is equal to n-falling factorial-r. 
**Combination** ~ A \_\_\_ of a set is an unordered selection of objects in a set. An unordered selection of r elements of a set is called an r-\_\_\_. This is equivalent to a subset with r elements.

**n-falling factorial k (n_k)** ~ This is equal to n*(n-1)*(n-2)*...*(n-k+1), n, k ∈ N, n >= k. 0_0 is defined as equal to one. &&n_n = n! (n-factorial), where 0! = 1.&& &&(n_k) = n!/(n-k)!&&

**Membership Tables** ~ This is a table of each combination of the atomic sets (original sets used to produce the sets on each side) that an element can belong to. ![](https://i.imgur.com/CJaBUbk.png?1)

**The Binomial Theorem** ~ Let x and y be variables, and let n be a nonnegative integer. Then \[(x + y)^n = \sum_{k=0}^n \begin{pmatrix}n\\k\end{pmatrix}x^{n-k}y^k = \begin{pmatrix}n\\0\end{pmatrix}x^n + \begin{pmatrix}n\\1\end{pmatrix}x^{n-1}y + \cdots + \begin{pmatrix}n\\n - 1\end{pmatrix} xy^{n-1} + \begin{pmatrix}n\\n\end{pmatrix}y^n\].

**Binomial Coefficient/n choose k** ~ Let \(n, k \in Z\). We define the \_\_\_ as \(\begin{pmatrix} n \\ k \end{pmatrix}\), read as \_\_\_, as the number of subsets of size k of an n element set. &&Observation: if k < 0 or n < 0,  n < 0 or k > n, n choose k is 0.&& &&Let&&Let n and r be %%For n and r be nonnegative integers with r <= n. Then C(n, r) = C(n, n - r) (think how Pascal's triangle is symmetric). && %%For remainder \(n, k \in N\), n choose 0 = 1 (empty set), n choose n = 1 (entire set), n choose 1 = n.%%

**Combinatorial Proof** ~ This is a proof that uses counting arguments to prove that both sides of the identity count the same objects but in identity count the same objects but in different ways or a proof that is based on showing that there is a bijection between the sets of objects counted by the two sides of the identity. &&These two types of proofs are called **double counting proofs** and **bijective proofs** respectively.&&

**Pascal's Identity** ~ Let \(n, k \in N\) with \(0 < k < n\). Then (n - 1) choose (k - 1) + (n - 1) choose k = n choose k. \[\begin{pmatrix}n + 1 \\ k \end{pmatrix} = \begin{pmatrix}n \\ k\end{pmatrix} + \begin{pmatrix}n \\ k - 1\end{pmatrix}\]

^^^
**Counting Formulas**

**Objects are distinguishable:**
Permutation - Repetition allowed = \(n^k\)
Combination - Repetition allowed = \(C(n + k - 1, r) = C(n + k - 1, n - 1)\)
Permutation - Repetition not allowed = \(P(n, k)\)
Combination - Repetition not allowed = \(C(n, k)\)
Permutation - Indistinguishable objects - \(\frac{n!}{n_1!n_2!\cdots n_k!\)

**Distributing Objects into Boxes:**
Distinguishable Objects + Distinguishable Boxes: \(\frac{n!}{n_1!n_2! \cdots n_k!}\).
Indistinguishable Objects + Distinguishable Boxes: \(\frac{(n+k-1)!}{(k-1)!}\)
^^^

**Pigeonhole Principle** ~ Let A and B be finite sets and let f : A -> B. If |A| > |B|, then f is not one-to-one. If |A| < |B|, then f is not onto.

## Relations

^^^
**(Binary) Relation** ~ A \_\_\_ R on a set P is a subset \(R \subset P x P\) (cartesian product). If \(a, b \in R \to a R b\). 
Relations can have 5 properties: 

1. **Reflexivity** - iff x R x in R for all x. \(\forall x((x, x) \in R\)
2. **Irreflexivity** - iff x not R x for all x. 
3. **Symmetry** - iff x R y implies y R x. 
4. **Antisymmetry** - iff (x R y) and (y R x) implies x = y. 
5. **Transitivity** - iff (x R y) and (y R z) then (x R z).
^^^

**Composite** ~ Let R be a relation from a set A to a set B and S a relation from B to a sB to a set C. The \_\_\_ of R and S is the relation consisting of ordered pairs (a, c), where \(a \in A, c\in C\), and for which there exists an element \(b \in B\) such that \((a, b \in R\text{ and } (b, c) \in S\). This is denoted by \(S \circ R\).

**Inverse Relation** ~ The \_\_\_ denoted \(R^(-1) = \{(y, x) : (x, y) \in R\}. This is relation is unique and exists only if a set is injective.
^^^
**Partial Order** ~ Let P be a set. A \_\_\_ on P is a binary relation \(\leq\) on P that, for all \(x, y, z \in P\), satisfies the three following conditions:
    (i) **Reflexivity** - \(x \leq x\)
    (ii) **Antisymmetry** - \(x \leq y\) and \(y \leq x\) implies \(x = y\)
    (iii) **Transitivity** - \(x \leq y\) and \(y \leq z\) implies \(x \leq z\)
^^^
**Equivalence Relation** ~ Let R be a relation on a set A. R is a \_\_\_ if R is reflexive, symmetric, and transitive. &&Two elements a and b that are related by an equivalence relation are called equivalent. The notation \(a tilde b\) is often used to denote that a and b are equivalent elements with respect to a particular equivalance relation.&& 
**Equivalence Class** ~ Let R be an equivalence relation on A. Let \(x \in A\). The \_\_\_ of x is the set of all elements in A that are related to x. &&If b is in the equivalent class of a with respect to R, then b is called a **representative** of this class. &&\[[a]_R = \{s \mid (a, s) \in R\}\]

**Question: Why can't an equivalence class be empty?**
**Partition** ~ Let A be a nonempty set. A \_\_\_ of A is a set of nonempty, pairwise disjoint sets whose union is A.a linear combination of two integers x and y (ax + by = \_\_\_(a, b)).